clear;
%*****************************************************************
% The following MATLAB code illustrates 2D ray tracing using the raytracing MEX
% code RT2D and the ionosphere generating MEX code PLASMA. All codes are  
% supplied for illustrative purposes alone and are designed to help students    
% with their understanding of ionospheric ray tracing. The background theory
% can be found in the textbook 'Analysis and Modeling of Radiowave Propagation' 
% (C.J.Coleman, CUP in 2016).
%*****************************************************************
% Chris Coleman - December 2016, EEE School, University of Adelaide
%*****************************************************************
%
%******************************************************************
%       Parameters for the ray tracing
%******************************************************************
along=133.7;alat=-23.5; % start corrdinates of propagation
htI=0.;                 % altitude of ray (km)
Bear=0;                 % initial bearing of ray (deg E of N)
freq=10;                % wave frequency (MHz)
ElevI=4.;               % initial elevation of ray (deg)
dElev=8.;               % elevation increment (deg)
nElev=3;                % number of elevations
%
%*****************************************************************
%       Parameters for 2D grid of ionospheric plasma frequencies
%*****************************************************************
SSN=100;KP=3;              % sunspot number and Kp magnetic index
month=3;hour=12;minute=0;  % month and time of simulation
Rmax=6000;                 % maximum range for simulation (km)
Hmax=600;                  % maximum height for simulation (km)
nRange=201;                % number of range samples for ionospheric slice
NumHt=201;                 % number of height samples for ionospheric slice
dRange=Rmax/(nRange-1);    % range step (km)
HtInc=Hmax/(NumHt-1);      % Height step (km)
%
%******************************************************************
% Generate ionospheric slice using the PLASMA MEX program.
%******************************************************************
% This program provides an nRange*NumHt grid of plasma frequency values
% in the direction Bear starting at the geopgraphic point (along,alat)
% with grid increment HtInc in height and dRange in Range. 
% The ionsphere is generated using Chapman layers with E and F1 layer 
% parameters derived from simple analytic models. The foF2 and hmF2
% values are based on CCIR ionospheric maps (see D.Bilitza, N.M.Sheikh,
% and R.Efrig,'A global model for the height of the F2-peak using 
% M(3000)F2 values from the CCIR numerical map', Telecomm.J., vol.46,
% pp.549-553, 1979).
%******************************************************************

fp=plasma(along,alat,Bear,SSN,month,hour,minute,HtInc,dRange,nRange,NumHt);

%******************************************************************
%  Perform raytracing using the RT2D MEX code (this code ignores
%  magneto-ionic effects)
%******************************************************************
for i=1:nElev
    Elev=ElevI+(i-1)*dElev;

[Npt,GP,PP,Loss,Rng,Alt]=RT2D(htI,Elev,freq,HtInc,dRange,nRange,NumHt,fp);

%******************************************************************
%       RT2D Input
%******************************************************************
%  
%     htI = height of ray launch (km)
%     Elev = initial elevation of ray (deg)
%     freq = wave frequency of ray (MHz)
%     HtInc = height increment on grid
%     dRange = range increment on grid
%     nRange = number of range dample points
%     numHt = number of height sample points
%     fp = NumHt * nRange grid of plasma frequencies
%     
%******************************************************************
%       RT2D Output
%******************************************************************
%                                                                
% Npt = number of sample points on ray  
% GP(*) = group range at sample point * (km)
% PP(*) = phase range at sample point * (km)
% Loss(*) = spreading loss at sample point * (dB)
% Rng(*) = range of sample point * (km)
% Alt(*) = altitude of sample point * (km)
%                                                                       
%*****************************************************************
% plot the slice of plasma frequency data at first elevation
%*****************************************************************
if(i==1)
MRayFig = figure;
MRayAxes = axes;
colormap(flipud(jet(64)));
%colormap(gray(12));
height = 0:HtInc:Hmax;
range = 0:dRange:Rmax;
imagesc(range,height,abs(fp(1:NumHt,1:nRange)));
xlabel('Range (km)');
ylabel('Altitude (km)');
title(strcat('Simulations at ',num2str(.1*floor(freq*10)),'MHz'));
set(MRayAxes,'YDir','normal');
MRayColorBar = colorbar;
ylabel(MRayColorBar,'Plasma Frequency (MHz)');
hold on;
end
%******************************************************************  
% plot rays
%******************************************************************
plot(Rng(1:Npt),Alt(1:Npt),'-w','linewidth',1);
hold on;
end
hold off;
%*****************************************************************
% end of code
%*****************************************************************
% It is suggested that the student tries plotting the array Loss in order
% to study the effect of ray focussing.
%*****************************************************************
