clear;
%*****************************************************************
% The following MATLAB code illustrates propagation losses in atmospheric
% propagation. Calculations are performed using a Kichhoff integral approach
% that is implemented in the KI2D MEX code. All codes are supplied for
% illustrative purposes alone and are designed to help students with their  
% understanding of atmospheric propagation. The background theory can
% be found in the textbook 'Analysis and Modeling of Radiowave Propagation' 
% (C.J.Coleman, CUP in 2016).
%*****************************************************************
% Chris Coleman - December 2016, EEE School, University of Adelaide
%*****************************************************************
%
%*****************************************************************
% 
% In the following example we calculate propagation over a land/sea   
% interface and demonstrate the recovery effect. The matrix of propagation
% losses is displayed on the screen by a MATLAB graphical function.
%*****************************************************************
%
%*****************************************************************
%       Define Basic Input Parameters
%*****************************************************************
hdip    = 20;       % Antenna Height above ground (m)
npo     = 2;        % Antenna polarisation (1 for horizontal polarisation and 2 for vertical polarisation)
f       = 3;        % Frequency (MHz)
zmax    = 200000;   % Maximum range (m)
hmax    = 2000;      % Maximum height (m) (maximum height at which you require propagation losses)
ndat    = 400;      % Number of ranges for ground parameter samples
kdat    = 2;        % Number of Atmospheric height samples (including sea level sample)
nrsamp  = 401;      % Number of range samples for output arrays
nhsamp  = 401;      % Number of height samples for output arrays

%*****************************************************************
%   Define the ground properties at ndat representative ranges 
%   through the 5*ndat matrix Ground. At range i    
%         Ground(1:5,i) = [range ht sig die rmsht] with
%         range = range of sample (m)
%         ht = ground height (m)
%         sig = conductivity of ground (S/m)
%         die = relative dielectric of the ground
%         rmsht = RMS height of any ground rougnhess(m)
%*****************************************************************
Ground=zeros(5,ndat);
   for i=1:ndat
       Alt(i)=0;
       if((i-1)/(ndat-1)<.25)
       Ground(:,i) = [(i-1)*zmax/(ndat-1); Alt(i); .002; 10;0];
       else
       Ground(:,i) = [(i-1)*zmax/(ndat-1); Alt(i); 5; 80;0]; 
       end
   end    

%*****************************************************************
%       Define the Atmospheric properties in terms of M units
%
%    htm(1) = duct height for an evaporative duct that can be added to the profile below
%    htm(2) = 1st sample height above sea level at which atmosphere is sampled
%    htm(3) = 2nd sample height 
%                ..........
%    htm(kdat) = kdat sample height
%       with 
%          am(1) = refractive index (in M units) at sea level
%          am(2) = refractive index at htm(2) 
%          am(3) = refractive index at htm(3)
%                 .........
%          am(kdat) = refractive index at htm(kdat)
%*****************************************************************
%     The following atmosphere contains an elevated duct of height 100m
%*****************************************************************
% Populate the atmospheric data arrays
htm=zeros(2);am=zeros(2);
htm=[0 1000];
am=[330 455];  
%******************************************************************
%       Call the calculation engine
%******************************************************************
%
aloss = KI2D(hdip,npo,f,ndat,Ground,kdat,htm,am,zmax,hmax,nrsamp,nhsamp);
%
%******************************************************************
%       KI2D Output
%******************************************************************
%  aloss = nrsamp x nhsamp array of propagation losses (in dB)
%  NB   nrsamp uniform spaced range samples over distance zmax
%       nhsamp uniform spaced height samples over height hmax
%
%******************************************************************
%       Plot the propagation loss results 
%******************************************************************
for i = 1:nrsamp
    for j = 1:nhsamp
        if(aloss(i,j)>160) aloss(i,j)=160; end
        if(aloss(i,j)<70) aloss(i,j)=70; end
    end
end
aloss(5,nhsamp)=110;
MRadarFig = figure;
MRadarAxes = axes;
colormap(flipud(jet(64)));
%colormap(gray(12));
height = 0:(hmax/(nhsamp-1)):hmax;
range = 0:(zmax/(nrsamp-1)):zmax;
imagesc(range(1:nrsamp)/1000,fliplr(height),abs(flipud(aloss(1:nrsamp,1:nhsamp)')));
xlabel('Range (km)');
ylabel('Altitude (m)');
title('KI2D Simulation Results');
title(strcat('Simulations at ',num2str(.1*floor(f*10)),'MHz'));
set(MRadarAxes,'YDir','normal');
MRadarColorBar = colorbar;
ylabel(MRadarColorBar,'Propagation Loss (dB)');
%*****************************************************************
% end of code
%*****************************************************************
% It is suggested that the student tries the some further simulations with 
% different frequencies and position of interface.
%*****************************************************************